==> xlniuxdata-vipgame-1.0.0-20141225.035105-5-sources.jar: com/xunlei/niux/data/vipgame/vo/CustomerNewUserPay.java <==
package com.xunlei.niux.data.vipgame.vo;


import com.ferret.common.dao.annotation.Table;


/**
 * 新用户大额充值统计实体类
 * @author lisu
 * 2014-12-05
 */
@Table(tableName = "customernewuserpay", pkFieldName = "seqId", pkFieldAssign = false)
public class CustomerNewUserPay {
		private Long seqId;
		private String fromTime;
		private String toTime;
		private Integer vipGrade;
	    private String customerService;
	    private String uid;
	    private Long callCount;
	    private Long payAmt;
	    private Long saleAmt;
		public Long getSeqId() {
			return seqId;
		}
		public void setSeqId(Long seqId) {
			this.seqId = seqId;
		}
		public String getFromTime() {
			return fromTime;
		}
		public void setFromTime(String fromTime) {
			this.fromTime = fromTime;
		}
		public String getToTime() {
			return toTime;
		}
		public void setToTime(String toTime) {
			this.toTime = toTime;
		}
		public Integer getVipGrade() {
			return vipGrade;
		}
		public void setVipGrade(Integer vipGrade) {
			this.vipGrade = vipGrade;
		}
		public String getCustomerService() {
			return customerService;
		}
		public void setCustomerService(String customerService) {
			this.customerService = customerService;
		}
		public String getUid() {
			return uid;
		}
		public void setUid(String uid) {
			this.uid = uid;
		}
		public Long getCallCount() {
			return callCount;
		}
		public void setCallCount(Long callCount) {
			this.callCount = callCount;
		}
		public Long getPayAmt() {
			return payAmt;
		}
		public void setPayAmt(Long payAmt) {
			this.payAmt = payAmt;
		}
		public Long getSaleAmt() {
			return saleAmt;
		}
		public void setSaleAmt(Long saleAmt) {
			this.saleAmt = saleAmt;
		}
	    
	    
	   
}

==> xlniuxdata-vipgame-1.0.65-20161208.125236-46-sources.jar: com/xunlei/niux/data/vipgame/vo/CustomerNewUserPay.java <==
package com.xunlei.niux.data.vipgame.vo;


import com.ferret.common.dao.annotation.Table;


/**
 * 新用户大额充值统计实体类
 * @author lisu
 * 2014-12-05
 */
@Table(tableName = "customernewuserpay", pkFieldName = "seqId", pkFieldAssign = false)
public class CustomerNewUserPay {
		private Long seqId;
		private String fromTime;
		private String toTime;
		private Integer vipGrade;
	    private String customerService;
	    private String uid;
	    private Long callCount;
	    private Long payAmt;
	    private Long saleAmt;
	    private String lastCaller;
	    
	    
	    
		public String getLastCaller() {
			return lastCaller;
		}
		public void setLastCaller(String lastCaller) {
			this.lastCaller = lastCaller;
		}
		public Long getSeqId() {
			return seqId;
		}
		public void setSeqId(Long seqId) {
			this.seqId = seqId;
		}
		public String getFromTime() {
			return fromTime;
		}
		public void setFromTime(String fromTime) {
			this.fromTime = fromTime;
		}
		public String getToTime() {
			return toTime;
		}
		public void setToTime(String toTime) {
			this.toTime = toTime;
		}
		public Integer getVipGrade() {
			return vipGrade;
		}
		public void setVipGrade(Integer vipGrade) {
			this.vipGrade = vipGrade;
		}
		public String getCustomerService() {
			return customerService;
		}
		public void setCustomerService(String customerService) {
			this.customerService = customerService;
		}
		public String getUid() {
			return uid;
		}
		public void setUid(String uid) {
			this.uid = uid;
		}
		public Long getCallCount() {
			return callCount;
		}
		public void setCallCount(Long callCount) {
			this.callCount = callCount;
		}
		public Long getPayAmt() {
			return payAmt;
		}
		public void setPayAmt(Long payAmt) {
			this.payAmt = payAmt;
		}
		public Long getSaleAmt() {
			return saleAmt;
		}
		public void setSaleAmt(Long saleAmt) {
			this.saleAmt = saleAmt;
		}
	    
	    
	   
}
